"""Import all plugins for them to autoregister
"""

from . import dnb
from . import swedbank
from . import maxibps
from . import danske
